@@ -5,6 +5,10 @@
    and is provided without guarantee or warrantee expressed or
    implied. This program is -not- in the public domain. */
 
+#ifdef __VMS
+#include <GL/vms_x_fix.h>
+#endif
+
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -311,7 +315,7 @@ probeDevices(void)
   XButtonInfoPtr b;
   XValuatorInfoPtr v;
   XAxisInfoPtr a;
-  int num_dev, btns, dials;
+  int num_dev = 0, btns = 0, dials = 0;
   int i, j, k;
 #endif /* !_WIN32 */
 
